#----
#
from mediphy._essence import retrieve_essence
import mediphy.mixes.procedure as procedure
#
#
import click
import rich
#
#
import pathlib
from os.path import dirname, join, normpath
import sys
import os
import time
#
#----

def restore_node (packet):
	version = packet ["version"]
	drop = packet ["drop"]

	essence = retrieve_essence ()

	the_dumps_path = essence ["monetary"] ["saves"] ["dumps"] ["path"]
	URL = essence ["monetary"] ["URL"]
	monetary_databases = essence ["monetary"] ["databases"]
	
	not_possible = []
	for monetary_database in monetary_databases:
		database_name = monetary_databases [ monetary_database ] ["alias"]
		database_collections = monetary_databases [ monetary_database ] ["collections"]
		
		for collection in database_collections:
			name = database_name + "." + collection + "." + version + ".dump.gzip"

			dump_path = str (normpath (join (
				the_dumps_path, 
				database_name, 
				collection, 
				name
			)))
			if (os.path.exists (dump_path) != True):
				not_possible.append (dump_path)
				continue;
				
			process_strand = [
				"mongorestore",
				"--uri",
				URL,
				f"--db={ database_name }",
				f"--collection={ collection }",
				#f"--out={ dump_path }",
				"--gzip",
				f"--archive={ dump_path }"
			]
			if (drop):
				process_strand.append ('--drop')
	
			procedure.go (
				script = process_strand
			)
			
			time.sleep (.25)
	
	os.system (f"chmod -R 777 '{ the_dumps_path }'")

	rich.print_json (data = {
		"not_possible": not_possible
	})	







'''
	from mediphy.frontiers.trends.monetary.DB_mediphy_trends.collection_vernacular.document.search import search_trends_vernacular
	search_trends_vernacular ({
		"filter": {
			"nature.identity.FDC ID": ""
		}
	})
'''



#/
#
from mediphy._essence import retrieve_essence
from mediphy.frontiers.trends.monetary.DB_mediphy_trends.connect import connect_to_mediphy_inventory
#
#
import ships.modules.exceptions.parse as parse_exception
#
#
import pymongo
#
#
import time
#
#\



def search_trends_vernacular (packet):
	filter = packet ["filter"]

	try:
		[ driver, DB_mediphy_trends ] = connect_to_mediphy_inventory ()
		collection_vernacular = DB_mediphy_trends ["collection_vernacular"]
	except Exception as E:
		print ("collection_vernacular connect exception:", E)
		
	treasures_roster = []
	try:	
		essence = retrieve_essence ()
		
		print ("filter:", filter)
		
		treasures_roster = []
		treasures = collection_vernacular.find (filter)
		for treasure in treasures:
			treasure ["_id"] = str (treasure ["_id"]) 
			
			treasures_roster.append (treasure)
		
	except Exception as E:
		print (parse_exception.now (E))
	
		raise Exception (E)
		pass;
		
	try:
		driver.close ()
	except Exception as E:
		print (parse_exception.now (E))
		print ("food collection disconnect exception:", E)	
		
		
	return treasures_roster;













''''
	from mediphy.frontiers.trends.monetary.DB_mediphy_trends.collection_vernacular._indexes import prepare_collection_vernacular_indexes
	prepare_collection_vernacular_indexes ()
"'''

#/
#
from mediphy.frontiers.trends.monetary.DB_mediphy_trends.collection_vernacular.document.insert import insert_document
from mediphy.frontiers.trends.monetary.DB_mediphy_trends.connect import connect_to_mediphy_inventory
#
#\

def prepare_collection_vernacular_indexes ():
	print ("prepare_collection_vernacular_indexes")

	[ driver, DB_mediphy_trends ] = connect_to_mediphy_inventory ()
	collection_vernacular = DB_mediphy_trends ["collection_vernacular"]
	
	collection_vernacular.create_index([('domain', 1)], unique=True)
	
	driver.close ()